@@ -24,8 +24,6 @@
 #  include "config.h"
 #endif
 
-#include <unistd.h>
-
 #include <gst/check/gstcheck.h>
 
 static GList *elements = NULL;
@@ -206,7 +204,7 @@ GST_END_TEST;
 Suite *
 states_suite (void)
 {
-  Suite *s = suite_create ("states");
+  Suite *s = suite_create ("states_ugly");
   TCase *tc_chain = tcase_create ("general");
 
   suite_add_tcase (s, tc_chain);
